@@ -128,6 +128,9 @@ statement at point to the 'use Module' section at the top.
 B<Extract Variable> - C<C-o e e v> -- Do the refactoring Extract
 Variable of the active region.
 
+B<Find Callers> - C>C-o e f c> -- Find callers of a method in the
+project and insert them as a comment in the source.
+
 B<Edit Test Count> -- C<C-o e t c> -- Increase the test count
 (e.g. "tests => 43")
 
@@ -1346,6 +1349,69 @@ Nice!
 =back
 
 
+
+=head3 Edit -- Find Callers
+
+C<C-o e f c> -- Find callers of a method in the current project, and
+insert the package->sub as a comment.
+
+This is for understanding where in the code base method calls
+originate.
+
+If point is in a comment on something that looks like a method call,
+look for that method. This can be in source code, or in a comment with
+callers. Insert the comment with callers above the current line.
+
+Otherwise, look for callers to the current sub. Insert the comment
+with callers above the sub declaration.
+
+Example: Point is in the sub C<price>:
+
+    package MyApp::Book;
+
+    sub price {
+    |
+
+Hit C<C-o e f c> and PerlySense will insert the three places where the
+price method is called:
+
+    package MyApp::Book;
+
+    #     MyApp::Book->discount_price
+    #     MyApp::User->total_book_cost
+    #    |MyApp::Author->daily_total_income
+    # MyApp::Book->price
+    sub price {
+
+Let's assume the method call chain for total_book_cost is interesting,
+so put the cursor on that line and again hit C<C-o e f c>. The callers
+for that method is now inserted on the line above.
+
+    package MyApp::Book;
+
+    #     MyApp::Book->discount_price
+    #         MyApp::Controller::User->user_details
+    #        |MyApp::User->total_cost
+    #     MyApp::User->total_book_cost
+    #     MyApp::Author->daily_total_income
+    # MyApp::Book->price
+    sub price {
+
+You can go on like this and add more callers to investigate the code
+structure.
+
+The cursor is placed conveniently to make it easy to subsequent
+callers to the call tree.
+
+If the same caller is already present in the comment, it is marked
+with a * to indicate that there's no point following them.
+
+The method of identifying callers works by method names alone, so
+there might be false positives, or uninteresting callers added to the
+list. Delete those lines to avoid clutter.
+
+
+
 =head3 Assist With -- Regex
 
 
@@ -1800,7 +1866,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense;
-$Devel::PerlySense::VERSION = '0.0214';
+$Devel::PerlySense::VERSION = '0.0215';
 
 
 use Spiffy -Base;
@@ -2627,6 +2693,62 @@ sub isFileInProject {
 
 
 
+=head2 raCallSiteForMethod(method => $nameMethod, dirOrigin => $dirOrigin)
+
+Find callers of $nameMethod in $dirOrigin.
+
+Return array ref of call sites.
+
+=cut
+sub raCallSiteForMethod {
+    my ($nameMethod, $dirOrigin) = Devel::PerlySense::Util::aNamedArg(["nameMethod", "dirOrigin"], @_);
+
+    $self->setFindProject(dir => $dirOrigin);
+
+    my @aMatch;
+    my %hSeen;
+    for my $file ( $self->oProject->aFileSourceCode ) {
+        my $source = slurp($file);
+
+        my $row = 0;
+        my $oDocument;
+        for my $line (split("\n", $source)) {
+            $row++;
+            $line =~ m/ -> \s* $nameMethod \b /x or next;
+            $line =~ m/ ^ \s* \# /x and next; # No comments
+            $oDocument ||= $self->oDocumentParseFile($file) or last;
+
+            my $oLocationSub = $oDocument->oLocationSubAt(
+                row => $row,
+                col => 1,
+            ) or next;
+
+            my $rhPropertySub = $oLocationSub->rhProperty;
+            my $namePackage = $rhPropertySub->{namePackage};
+            my $nameSub = $rhPropertySub->{nameSub};
+
+            $hSeen{ "$namePackage->$nameSub" }++ and next;
+
+            push(
+                @aMatch,
+                {
+                    file    => $file,
+                    package => $namePackage,
+                    method  => $nameSub,
+                },
+            );
+        }
+    }
+
+    ###JPL: make any file names relative to project
+
+    return \@aMatch;
+}
+
+
+
+
+
 =head1 IMPLEMENTATION METHODS
 
 =head2 fileFindLookingAround($fileModuleBase, $dirOrigin, $nameModule?)
