@@ -24,7 +24,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense::Project;
-$Devel::PerlySense::Project::VERSION = '0.0214';
+$Devel::PerlySense::Project::VERSION = '0.0215';
 
 
 use Spiffy -Base;
@@ -34,6 +34,7 @@ use File::Basename;
 use Path::Class;
 use File::Slurp;
 use File::chdir;
+use File::Find::Rule;
 use Perl::Critic 1.105;
 use List::MoreUtils qw/ uniq /;
 
@@ -709,6 +710,23 @@ sub raFileProjectOther {
 
 
 
+=head2 aFileSourceCode()
+
+Return array with file names with perl source code in the project.
+
+# TODO: also look inside files without extension and check for perlyness
+
+=cut
+sub aFileSourceCode {
+    return File::Find::Rule
+        ->name("*.pm", "*.pl")
+        ->in( $self->aDirIncAbsolute );
+}
+
+
+
+
+
 
 1;
 
